@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclObj.c 1.47 97/10/30 13:39:00
+ * RCS: @(#) $Id: tclObj.c,v 1.3 1998/10/05 22:32:09 escoffon Exp $
  */
 
 #include "tclInt.h"
@@ -134,6 +134,7 @@ InitTypeTable()
     Tcl_RegisterObjType(&tclStringType);
     Tcl_RegisterObjType(&tclListType);
     Tcl_RegisterObjType(&tclByteCodeType);
+    Tcl_RegisterObjType(&tclProcBodyType);
 
     tclEmptyStringRep = (char *) ckalloc((unsigned) 1);
     tclEmptyStringRep[0] = '\0';
@@ -718,17 +719,6 @@ Tcl_DuplicateObj(objPtr)
  *----------------------------------------------------------------------
  */
 
-char *
-Tcl_GetString(objPtr)
-    register Tcl_Obj *objPtr;
-{
-    if (objPtr->bytes == NULL) {
-	objPtr->typePtr->updateStringProc(objPtr);
-    }
-    return objPtr->bytes;
-
-}
-
 char *
 Tcl_GetStringFromObj(objPtr, lengthPtr)
     register Tcl_Obj *objPtr;	/* Object whose string rep byte pointer
@@ -737,9 +727,14 @@ Tcl_GetStringFromObj(objPtr, lengthPtr)
 				 * string rep's byte array length should be
 				 * stored. If NULL, no length is stored. */
 {
-    if (objPtr->bytes == NULL) {
-	objPtr->typePtr->updateStringProc(objPtr);
+    if (objPtr->bytes != NULL) {
+	if (lengthPtr != NULL) {
+	    *lengthPtr = objPtr->length;
+	}
+	return objPtr->bytes;
     }
+
+    objPtr->typePtr->updateStringProc(objPtr);
     if (lengthPtr != NULL) {
 	*lengthPtr = objPtr->length;
     }
