@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclProc.c,v 1.16 1998/10/05 22:32:10 escoffon Exp $
+ * RCS: @(#) $Id: tclProc.c,v 1.17 1999/02/03 00:55:06 stanton Exp $
  */
 
 #include "tclInt.h"
@@ -70,7 +70,6 @@ Tcl_ProcObjCmd(dummy, interp, objc, objv)
     Namespace *nsPtr, *altNsPtr, *cxtNsPtr;
     Tcl_Command cmd;
     Tcl_DString ds;
-    int result;
 
     if (objc != 4) {
 	Tcl_WrongNumArgs(interp, 1, objv, "name args body");
@@ -84,12 +83,9 @@ Tcl_ProcObjCmd(dummy, interp, objc, objv)
      */
     
     fullName = Tcl_GetStringFromObj(objv[1], (int *) NULL);
-    result = TclGetNamespaceForQualName(interp, fullName,
-	    (Namespace *) NULL, TCL_LEAVE_ERR_MSG,
-            &nsPtr, &altNsPtr, &cxtNsPtr, &procName);
-    if (result != TCL_OK) {
-        return result;
-    }
+    TclGetNamespaceForQualName(interp, fullName, (Namespace *) NULL,
+       /*flags*/ 0, &nsPtr, &altNsPtr, &cxtNsPtr, &procName);
+
     if (nsPtr == NULL) {
         Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
 		"can't create procedure \"", fullName,
