@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclMacLoad.c 1.20 97/11/20 18:39:20
+ * RCS: @(#) $Id: tclMacLoad.c,v 1.2 1998/09/14 18:40:05 stanton Exp $
  */
 
 #include <CodeFragments.h>
@@ -31,7 +31,6 @@
 #include "tclPort.h"
 #include "tclInt.h"
 #include "tclMacInt.h"
-#include "::compat:dlfcn.h"
 
 #if GENERATINGPOWERPC
     #define OUR_ARCH_TYPE kPowerPCCFragArch
@@ -77,7 +76,6 @@ struct CfrgItem {
     Str255	name;		/* This is actually variable sized. */
 };
 typedef struct CfrgItem CfrgItem;
-
 
 /*
  *----------------------------------------------------------------------
@@ -109,87 +107,32 @@ TclLoadFile(
     Tcl_PackageInitProc **proc2Ptr)
 				/* Where to return the addresses corresponding
 				 * to sym1 and sym2. */
-{
-    VOID *handle = NULL;
-
-    handle = dlopen(fileName, RTLD_NOW | RTLD_GLOBAL);
-    if (handle == NULL) {
-	Tcl_AppendResult(interp, "couldn't load file \"", fileName,
-		"\": ", dlerror(), (char *) NULL);
-	return TCL_ERROR;
-    }
-    *proc1Ptr = (Tcl_PackageInitProc *) dlsym(handle, (char *) sym1);
-    *proc2Ptr = (Tcl_PackageInitProc *) dlsym(handle, (char *) sym2);
-    return TCL_OK;
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * dlopen --
- *
- *	This function is an implementation of dlopen() for the Mac.
- *
- * Results:
- *	Returns the handle of the newly loaded library, or NULL on
- *	failure.
- *
- * Side effects:
- *	Loads the specified library into the process.
- *
- *----------------------------------------------------------------------
- */
-
-static Str255 errName;
-
-VOID *
-dlopen(path, mode)
-    CONST char *path;
-    int mode;
 {
     CFragConnectionID connID;
     Ptr dummy;
     OSErr err;
+    CFragSymbolClass symClass;
     FSSpec fileSpec;
     short fragFileRef, saveFileRef;
     Handle fragResource;
     UInt32 offset = 0;
     UInt32 length = kCFragGoesToEOF;
     char packageName[255];
-    CONST char* pkgGuess;
-    char* p;
+    Str255 errName;
     
     /*
-     * First thing we must do is infer the package name from the file
-     * name.  This is kind of dumb since the caller actually knows
+     * First thing we must do is infer the package name from the sym1
+     * variable.  This is kind of dumb since the caller actually knows
      * this value, it just doesn't give it to us.
      */
+    strcpy(packageName, sym1);
+    *packageName = (char) tolower(*packageName);
+    packageName[strlen(packageName) - 5] = NULL;
     
-    if ((pkgGuess = strrchr(path,':')) != NULL) {
-      pkgGuess++;
-    } else {
-      pkgGuess = path;
-    }
-    if (!strncmp(pkgGuess,"lib",3)) {
-      pkgGuess+=3;
-    }
-    strcpy(packageName,pkgGuess);
-    p = packageName;
-    if ((*p) && islower(UCHAR(*p++))) {
-      packageName[0] = (char) toupper(UCHAR(packageName[0]));
-    }
-    while (isalpha(UCHAR(*p)) || (*p == '_')) {
-      if (isupper(UCHAR(*p))) {
-        *p = (char) tolower(UCHAR(*p));
-      }
-      p++;
-    }
-    *p = 0;
-
-    err = FSpLocationFromPath(strlen(path), (char *) path, &fileSpec);
+    err = FSpLocationFromPath(strlen(fileName), fileName, &fileSpec);
     if (err != noErr) {
-	strcpy((char *) errName, "file not found");
-	return (VOID *) NULL;
+	interp->result = "could not locate shared library";
+	return TCL_ERROR;
     }
     
     /*
@@ -247,9 +190,28 @@ dlopen(path, mode)
 	    kLoadCFrag, &connID, &dummy, errName);
     if (err != fragNoErr) {
 	p2cstr(errName);
-	return (VOID *) NULL;
+	Tcl_AppendResult(interp, "couldn't load file \"", fileName,
+	    "\": ", errName, (char *) NULL);
+	return TCL_ERROR;
     }
-    return (VOID *) connID;
+    
+    c2pstr(sym1);
+    err = FindSymbol(connID, (StringPtr) sym1, (Ptr *) proc1Ptr, &symClass);
+    p2cstr((StringPtr) sym1);
+    if (err != fragNoErr || symClass == kDataCFragSymbol) {
+	interp->result =
+	    "could not find Initialization routine in library";
+	return TCL_ERROR;
+    }
+
+    c2pstr(sym2);
+    err = FindSymbol(connID, (StringPtr) sym2, (Ptr *) proc2Ptr, &symClass);
+    p2cstr((StringPtr) sym2);
+    if (err != fragNoErr || symClass == kDataCFragSymbol) {
+	*proc2Ptr = NULL;
+    }
+    
+    return TCL_OK;
 }
 
 /*
@@ -281,90 +243,3 @@ TclGuessPackageName(
 {
     return 0;
 }
-
-/*
- *----------------------------------------------------------------------
- *
- * dlsym --
- *
- *	This function is an alternative for the system function
- *	GetProcAddress. It returns the address of a
- *	symbol, give the handle returned by dlopen().
- *
- * Results:
- *	Returns the address of the symbol in the dll.
- *
- * Side effects:
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-VOID *
-dlsym(handle, symbol)
-    VOID *handle;
-    CONST char *symbol;
-{
-    VOID *procPtr;
-    char sym1[255];
-    OSErr err;
-    SymClass symClass;
-
-    strcpy(sym1, symbol);
-    c2pstr(sym1);
-
-    err = FindSymbol((ConnectionID) handle, (StringPtr) sym1,
-	    (Ptr *) &procPtr, &symClass);
-    if (err != fragNoErr || symClass == kDataCFragSymbol) {
-	procPtr = (VOID *) NULL;
-    }
-    return procPtr;
-}
-
-/*
- *----------------------------------------------------------------------
- *
- * dlerror --
- *
- *	This function returns a string describing the error which
- *	occurred in dlopen().
- *
- * Results:
- *	Returns an error message.
- *
- * Side effects:
- *	None.
- *
- *----------------------------------------------------------------------
- */
-
-char *
-dlerror()
-{
-    return (char *) errName;
-}
-
-
-/*
- *----------------------------------------------------------------------
- *
- * dlclose --
- *
- *	Not implemented yet.
- *
- * Results:
- *	Always returns 0 (= O.K.)
- *
- * Side effects:
- *	None
- *
- *----------------------------------------------------------------------
- */
-
-int
-dlclose(handle)
-    VOID *handle;
-{
-    return 0;
-}
-
