@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclWinInit.c 1.32 97/06/24 17:28:26
+ * RCS: @(#) $Id: tclWinInit.c,v 1.12 1999/02/02 18:36:31 stanton Exp $
  */
 
 #include "tclInt.h"
@@ -58,8 +58,6 @@ typedef struct {
 #define PROCESSOR_ARCHITECTURE_UNKNOWN 0xFFFF
 #endif
 
-DWORD TclWinThreadId;
-
 /*
  * The following arrays contain the human readable strings for the Windows
  * platform and processor values.
@@ -220,8 +218,10 @@ TclPlatformInit(interp)
 	    argv[2] = NULL;
 	    Tcl_DStringSetLength(&ds, 0);
 	    Tcl_SetVar(interp, "tcl_pkgPath", Tcl_JoinPath(2, argv, &ds),
-		    TCL_GLOBAL_ONLY|TCL_LIST_ELEMENT|TCL_APPEND_VALUE);
+		    TCL_GLOBAL_ONLY|TCL_LIST_ELEMENT);
 	}
+    } else {
+	Tcl_SetVar(interp, "tcl_pkgPath", "", TCL_GLOBAL_ONLY);
     }
 
     /*
@@ -242,6 +242,18 @@ TclPlatformInit(interp)
 		TCL_GLOBAL_ONLY);
     }
 
+#ifdef _DEBUG
+    /*
+     * The existence of the "debug" element of the tcl_platform array indicates
+     * that this particular Tcl shell has been compiled with debug information.
+     * Using "info exists tcl_platform(debug)" a Tcl script can direct the 
+     * interpreter to load debug versions of DLLs with the load command.
+     */
+
+    Tcl_SetVar2(interp, "tcl_platform", "debug", "1",
+	    TCL_GLOBAL_ONLY);
+#endif
+
     /*
      * Set up the HOME environment variable from the HOMEDRIVE & HOMEPATH
      * environment variables, if necessary.
@@ -267,7 +279,6 @@ TclPlatformInit(interp)
     }
 
     Tcl_DStringFree(&ds);
-    TclWinThreadId = GetCurrentThreadId();
 }
 
 /*
@@ -298,10 +309,7 @@ Tcl_Init(interp)
 	    return (TCL_ERROR);
 	};
     }
-    if (Tcl_Eval(interp, initScript) == TCL_ERROR) {
-	return TCL_ERROR;
-    }
-    return TCL_OK;
+    return(Tcl_Eval(interp, initScript));
 }
 
 /*
@@ -379,7 +387,7 @@ Tcl_SourceRCFile(interp)
 		if (Tcl_EvalFile(interp, fullName) != TCL_OK) {
 		    errChannel = Tcl_GetStdChannel(TCL_STDERR);
 		    if (errChannel) {
-			Tcl_Write(errChannel, Tcl_GetStringResult(interp), -1);
+			Tcl_Write(errChannel, interp->result, -1);
 			Tcl_Write(errChannel, "\n", 1);
 		    }
 		}
@@ -388,28 +396,3 @@ Tcl_SourceRCFile(interp)
         Tcl_DStringFree(&temp);
     }
 }
-
-/*
- *----------------------------------------------------------------------
- *
- * TclPlatformAsyncMark --
- *
- *	Process asynchronous event on Windows
- *
- * Results:
- *	None
- *
- *----------------------------------------------------------------------
- */
-
-void
-TclPlatformAsyncMark(async)
-    Tcl_AsyncHandler async;		/* Token for handler. */
-{
-    /*
-     * Need a way to kick
-     * the Windows event loop and tell it to go look at asynchronous
-     * events.
-     */
-    PostThreadMessage(TclWinThreadId, WM_USER, 0, 0);
-}
