@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclWinSock.c,v 1.3 1998/09/14 18:40:20 stanton Exp $
+ * RCS: @(#) $Id: tclWinSock.c,v 1.5 1999/02/03 00:51:20 stanton Exp $
  */
 
 #include "tclInt.h"
@@ -699,7 +699,7 @@ SocketEventProc(evPtr, flags)
 	}
 
     }
-    if (events & FD_WRITE) {
+    if (events & (FD_WRITE | FD_CONNECT)) {
 	mask |= TCL_WRITABLE;
     }
 
@@ -902,6 +902,13 @@ CreateSocket(interp, port, host, server, myaddr, myport, async)
 	goto error;
     }
 
+    /*
+     * Win-NT has a misfeature that sockets are inherited in child
+     * processes by default.  Turn off the inherit bit.
+     */
+
+    SetHandleInformation( (HANDLE) sock, HANDLE_FLAG_INHERIT, 0 );
+	
     /*
      * Set kernel space buffering
      */
@@ -1396,6 +1403,13 @@ TcpAccept(infoPtr)
         return;
     }
 
+    /*
+     * Win-NT has a misfeature that sockets are inherited in child
+     * processes by default.  Turn off the inherit bit.
+     */
+
+    SetHandleInformation( (HANDLE) newSocket, HANDLE_FLAG_INHERIT, 0 );
+	
     /*
      * Add this socket to the global list of sockets.
      */
@@ -1727,6 +1741,24 @@ TcpGetOptionProc(instanceData, interp, optionName, dsPtr)
         len = strlen(optionName);
     }
 
+    if ((len > 1) && (optionName[1] == 'e') &&
+                    (strncmp(optionName, "-error", len) == 0)) {
+       int optlen;
+       int err, ret;
+    
+       optlen = sizeof(int);
+       ret = TclWinGetSockOpt(sock, SOL_SOCKET, SO_ERROR,
+                              (char *)&err, &optlen);
+       if (ret == SOCKET_ERROR) {
+           err = (*winSock.WSAGetLastError)();
+       }
+       if (err) {
+           TclWinConvertWSAError(err);
+           Tcl_DStringAppend(dsPtr, Tcl_ErrnoMsg(Tcl_GetErrno()), -1);
+       }
+       return TCL_OK;
+    }
+
     if ((len == 0) ||
             ((len > 1) && (optionName[1] == 'p') &&
                     (strncmp(optionName, "-peername", len) == 0))) {
@@ -1854,7 +1886,7 @@ TcpWatchProc(instanceData, mask)
 	infoPtr->watchEvents |= (FD_READ|FD_CLOSE|FD_ACCEPT);
     }
     if (mask & TCL_WRITABLE) {
-	infoPtr->watchEvents |= (FD_WRITE);
+       infoPtr->watchEvents |= (FD_WRITE|FD_CONNECT);
     }
 
     /*
